import Vue from "vue"
let prototype = Vue.prototype;

export default {
    /**
     * 登录平台
     */
    platformLogin() {
        return new Promise((resolve, reject) => {
            // #ifndef H5
            uni.login({
                provider: "weixin",
                success(result) {
                    prototype.$request({
                        api: 'user.openId',
                        data: {
                            code: result.code
                        }
                    }).then((response) => {
                        resolve(response.data);
                    });
                }
            });
            // #endif
        });
    },
    /**
     * 发送验证码
     */
    sendVerificationCode(mobile) {
        return new Promise((resolve, reject) => {
            if (!prototype.$test.mobile(mobile)) {
                return reject('请输入正确的手机号码');
            }
            prototype.$request({
                api: 'user.sendCode',
                data: {
                    username: mobile,
                },
            }).then((res) => {
                if (res.code == 1) {
                    return resolve();
                } else {
                    return reject(response.msg);
                }
            });
        });
    },
    /**
     * 用户注册
     */
    register(userData, verificationCode) {
        return new Promise((resolve, reject) => {
            if (!prototype.$test.mobile(userData.mobile)) {
                return reject('请输入正确的手机号码');
            }
            if (userData.password.length < 6 || userData.password.length > 16) {
                return reject('密码在6至16位字符之间');
            }
            this.platformLogin().then(res => {
                prototype.$request({
                    api: 'user.register',
                    data: {
                        username: userData.mobile,
                        password: userData.password,
                        verification_code: verificationCode,
                        openid: res.openid,
                        types: 1,
                    }
                }).then((response) => {
                    if (response.code == 1) {
                        return resolve(response);
                    } else {
                        return reject(response.msg);
                    }
                });
            });
        });
    }
}
